@@ -1,7 +1,6 @@
 # coding=utf-8
 import json
 import logging
-import re
 import sys
 import uuid
 from datetime import datetime
@@ -31,7 +30,6 @@ _current_framework = None
 _logger = get_library_logger(__name__)
 _request_util = None
 _default_formatter = None
-_exclude_URL_patterns = []
 
 
 def get_correlation_id(request=None):
@@ -82,16 +80,17 @@ def config_root_logger():
         & remove duplicate handlers for request instrumentation logging.
         Please made sure that you call this after you called "logging.basicConfig() or logging.getLogger('root')
     """
-    global _default_formatter
 
-    if len(logging.root.handlers) > 0:
+    if not logging.root.handlers:
         _logger.error(
             "No logging handlers found for root logger. Please made sure that you call this after you called "
             "logging.basicConfig() or logging.getLogger('root')")
+        return
 
     if ENABLE_JSON_LOGGING:
         ENABLE_JSON_LOGGING_DEBUG and _logger.debug("Update root logger to using JSONLogFormatter")
 
+        global _default_formatter
         util.update_formatter_for_loggers([logging.root], _default_formatter)
 
 
@@ -171,8 +170,6 @@ def init_request_instrument(app=None, custom_formatter=None, exclude_url_pattern
         if not issubclass(custom_formatter, logging.Formatter):
             raise ValueError('custom_formatter is not subclass of logging.Formatter', custom_formatter)
 
-    global _exclude_URL_patterns
-    _exclude_URL_patterns = exclude_url_patterns
     configurator = _current_framework['app_request_instrumentation_configurator']()
     configurator.config(app, exclude_url_patterns=exclude_url_patterns)
 
@@ -265,13 +262,13 @@ class JSONRequestLogFormatter(BaseJSONFormatter):
         json_log_object = super(JSONRequestLogFormatter, self)._format_log_object(record, request_util)
         request = record.request_info.request
         request_adapter = request_util.request_adapter
-        path = request_adapter.get_path(request)
+
         length = request_adapter.get_content_length(request)
         json_log_object.update({
             "type": "request",
             "correlation_id": request_util.get_correlation_id(request),
             "remote_user": request_adapter.get_remote_user(request),
-            "request": path,
+            "request": request_adapter.get_path(request),
             "referer": request_adapter.get_http_header(request, 'referer', EMPTY_VALUE),
             "x_forwarded_for": request_adapter.get_http_header(request, 'x-forwarded-for', EMPTY_VALUE),
             "protocol": request_adapter.get_protocol(request),
